#
# spec file for package kaidan
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

Name:           kaidan
Version:        0.11.0
Release:        1.2
Summary:        A XMPP client based on KDE Framework
License:        AML AND GPL-3.0-or-later AND SUSE-GPL-3.0+-with-openssl-exception AND MIT AND CC-BY-SA-4.0
URL:            https://www.kaidan.im
Source0:        https://download.kde.org/unstable/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/unstable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        kaidan.keyring
# PATCH-FIX-UPSTREAM: https://invent.kde.org/network/kaidan/-/merge_requests/1328
Patch0:         drop_quick_compiler_option.patch
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{qt6_version}
# Both Qt 5 and Qt 6 flavors use the same cmake config name, use the -devel package name
# BuildRequires:  cmake(KQuickImageEditor)
BuildRequires:  kquickimageeditor6-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-declarative-tools >= %{qt6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 1.4.0
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Prison) >= %{kf6_version}
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(QXmppQt6) >= 1.9.0
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Location) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Positioning) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Sql) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  cmake(ZXing) >= 1.0.8
BuildRequires:  pkgconfig(icu-uc) >= 61.0
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-prison-imports >= %{kf6_version}
Requires:       kirigami-addons6 >= 1.4.0
Requires:       kquickimageeditor6-imports
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-location >= %{qt6_version}
Requires:       qt6-multimedia-imports >= %{qt6_version}
Requires:       qt6-positioning-imports >= %{qt6_version}
Requires:       qt6-sql-sqlite >= %{qt6_version}

%description
Kaidan is a simple Jabber/XMPP client providing a user-interface using
Kirigami and QtQuick. The back-end of Kaidan is entirely written in C++
using the qxmpp XMPP client library and Qt 6.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-qt

%fdupes %{buildroot}

%files
%license LICENSES/*
%doc README.md NEWS.md
%dir %{_kf6_sharedir}/kaidan
%{_kf6_applicationsdir}/im.kaidan.kaidan.desktop
%{_kf6_appstreamdir}/im.kaidan.kaidan.appdata.xml
%{_kf6_bindir}/kaidan
%{_kf6_debugdir}/kaidan.categories
%{_kf6_iconsdir}/hicolor/*/apps/kaidan.*
%{_kf6_notificationsdir}/kaidan.notifyrc
%{_kf6_sharedir}/kaidan/images
%{_kf6_sharedir}/kaidan/providers*

%files lang -f %{name}.lang

%changelog
* Sun Feb 16 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.11.0:
  * Features:
    + Highlight public XMPP provider titles while card is expanded
    + Round corners of cards and buttons
    + Add fading in/out hover effect to map previews
    + Collapse contact profiles by default if they have more than 3 entries
    + Show colored check mark for delivered messages instead of none to avoid
    message bubble resizing
  * Bugfixes:
    + Fix opening public MUC-based group chats via another XMPP client
    + Fix playing voice messages and changing playing position
    + Fix updating message reactions that could not be sent instead of adding
    them a second time
    + Fix updating group chat users in user interface
    + Fix displaying message reaction details
    + Update filtering contacts by labels even if label list is not open
    anymore
    + Fix scrolling media overview
    + Fix updating draft messages
  * Notes:
    + Kaidan requires Qt 6.6 now
- Add drop_quick_compiler_option.patch
* Sun Dec 15 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.10.1
  * Fix displaying files of each message in appropriate message
    bubble
  * Fix sending fallback messages for clients not supporting
    XEP-0447: Stateless file sharing
  * Fix margins within message bubbles
  * Fix hiding hidden message part
  * Fix displaying marker for new messages
* Thu Dec 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.10.0:
  https://www.kaidan.im/2024/12/09/kaidan-0.10.0/
* Fri Dec  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.9.2
  * Fix file extension for downloads when mime type is empty
  * Fix file downloads without a source URL could be started
  * Fix file messages are never marked as sent
  * Fix message body of previous file selection was used
  * Fix missing receipt request (for green checkmark) on media messages
  * Fix outgoing encrypted media messages are displayed as unencrypted
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Sun Jul 14 2024 hui <sturm-fr@web.de>
- Fix dependency which prevented Kaidan from start boo#1227744
* Mon Mar 25 2024 Christophe Marin <christophe@krop.fr>
- Replace the 'cmake(KQuickImageEditor)' BuildRequires with
  kquickimageeditor-devel to pick the correct flavor
- Build with GCC 13 on Leap 15
* Mon May 22 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.9.1:
  * The published tar for 0.9.0 contained the wrong version
- Add the lang package
- Drop 0001-QrCodeDecoder-Replace-deprecated-BarcodeFormat-QR_CO.patch, 0001-QrCodeGenerator-Replace-deprecated-BarcodeFormat-QR_.patch and 0001-Support-ZXing-2.0.patch
* Fri May  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.9.0
  * End-to-end encryption with OMEMO 2 for messages, files and
    metadata including an easy trust management
  * XMPP Providers support for an easy onboarding
  * Message reactions for sending emojis upon a message
  * Read markers showing which messages a contact has read
  * Message drafts to send entered messages later after switching
    chats or restarting Kaidan
  * Message search for messages that are not yet loaded
  * New look of the chat background and message bubbles including
    grouped messages from the same author
  * Chat pinning for reordering chats
  * Public group chat search (without group chat support yet)
  * New contact and account details including the ability to
    change the own profile picture
  * Restored window position on start
* Thu Feb  9 2023 Christophe Marin <christophe@krop.fr>
- Add patches to fix build with ZXing >= 2.0:
  * 0001-QrCodeDecoder-Replace-deprecated-BarcodeFormat-QR_CO.patch
  * 0001-QrCodeGenerator-Replace-deprecated-BarcodeFormat-QR_.patch
  * 0001-Support-ZXing-2.0.patch
* Fri Oct  1 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 0.8.0:
  Features:
  * Add typing notifications (XEP-0085: Chat State Notifications)
  * Add message history syncing (XEP-0313: Message Archive Management)
  * Window size is restored
  * The server's website link is displayed if account creation is disabled
  * Improved user strings & descriptions
* Sat Feb 27 2021 Mia Herkt <mia@0x0.st>
- Update to 0.7.0
  Features:
  * Display client information (name, version, OS) of contacts
  * Drag'n'drop for sending files
  * Allow pasting images from the clipboard (Ctrl+Shift+V) into
    the chat
  * Allow inserting newlines using Shift+Enter
  * Add configuration of custom hostname/port
  * Favourite emojis are shown by default now
  * Search emojis by ":<name>"
  * Display connection errors in the global drawer after login
  * Improved design of media preview sheets
  * Restructure message sending bar
  Bugfixes:
  * Do not interpret random URLs as files anymore
  * Fix the style of buttons when using Material style
  * Fix file dialog and media drawer opening in some cases
  * Fix opening of the LoginPage when scanning QR code without
    password
  Notes:
  * Kaidan requires Qt 5.14 now
- Changes in 0.6.0:
  Features:
  * When offline, messages are cached now to be sent later
  * It's allowed to also correct other messages than the last one
    now
  * Also pending (unsent) messages can be corrected now
  * Chats can be opened from the notifications now
  * New option to permanently hide your password in Kaidan
  * New buttons for easily copying your jid and password
  * Moved account management pages into the settings
  * The cursor is moved to the end of the text field when
    correcting a message now
  * Scanning QR codes without a password works now and results in
    only the JID being set
  * The roster is called contact list now
  * The resource for the displayed presence is picked with fixed
    rules now (it was random before which resource is displayed)
  * Handle notifications differently on GNOME to keep them in the
    notifications area
  * Switched to the upstream HTTP File Upload implementation
  * Code refactoring and partial rewrite of the following classes:
    Kaidan, ClientWorker, RosterManager, PresenceCache,
    DownloadManager, TransferCache, QrCodeDecoder
  Bugfixes:
  * Playback issues in media video preview
  * Messages sent from other of your devices are displayed as they
    were sent by the chat partner
  * Notifications are shown persistently on the screen
  * Roster names are not updated in the database
  * Roster items are not updated in the model correctly
  * All sheets contain two headers: It uses the new built-in header
    property now
  * Unreadable buttons with white text on withe background in some
    styles
  * Database version isn't saved correctly
  * Errors when building with newer ZXing versions
  Notes:
  * Kaidan requires a C++17-compliant compiler now
- Drop 0001-Port-deprecations-and-little-refactoring-of-the-QrCo.patch
* Sun Aug 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.5.0
  * Add parsing of XMPP URIs
  * Add QR code scanning and generation
  * Add contact search
  * Add muting notifications for messages of contacts
  * Add renaming contacts
  * Show user profile information
  * Add extended multimedia support
  * Add message search
  * Redesign contact list, text avatar, counter for unread messages, chat page, chat message bubble
  * Add option for enabling or disabling an account temporarily
  * Refactor login screen with hints for invalid credentials and better usage of keyboard keys
  * Add message quoting
  * Truncate very long messages to avoid crashing Kaidan or using it to full capacity
  * Add button with link for issue tracking to about page
  * Improve messages for connection errors
  * Add account deletion
  * Redesign logo and global drawer banner
  * Add onboarding with registration, normal login and QR code login
  * Add OARS rating
  * Add secondary roster sorting by contact name
  * Add support for recording audio and video messages
  * Add Kaidan to KDE’s F-Droid repository
  * Improve build scripts for better cross-platform support
  * Refactor code for better performance and stability
  * Add documentation to achieve easier maintenance
- Add upstream patch:
  * 0001-Port-deprecations-and-little-refactoring-of-the-QrCo.patch
* Wed Jul 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.4.1
  * Fix SSL problems for AppImage
  * Fix connection problems
  * Keep QXmpp v0.8.3 compatibility
* Tue Jul  9 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.4.0 final release
- Update build requirements
- Update URLs
* Sun May 12 2019 Andrey Karepin <egdfree@opensuse.org>
- Initial package for openSUSE
